/*!
 * @module angularjs-toast
 * @description A Simple toast notification service for AngularJS pages
 * @version v3.0.0
 * @link https://github.com/sibiraj-s/angularjs-toast#readme
 * @licence MIT License, https://opensource.org/licenses/MIT
 */

"use strict";

(function () {
  'use strict';

  var $toastFactory, $toastProvider, getUniqId;

  getUniqId = function getUniqId() {
    var s4;

    s4 = function s4() {
      return ((1 + Math.random()) * 0x10000 | 0).toString(16).substring(1);
    };

    return "".concat(new Date().getTime(), "-").concat(s4(), "-").concat(s4(), "-").concat(s4());
  };

  $toastProvider = function $toastProvider() {
    var defaultOptions, options;
    defaultOptions = {
      container: 'body',
      defaultToastClass: 'alert-success',
      timeout: 5 * 1000,
      dismissible: true,
      maxToast: 7,
      position: 'right',
      containerClass: '',
      insertFromTop: true
    };
    options = defaultOptions;
    return {
      configure: function configure(c) {
        options = angular.extend({}, defaultOptions, c);
      },
      $get: function $get() {
        return options;
      }
    };
  };

  $toastFactory = function $toastFactory($rootScope, $http, $templateCache, $compile, $timeout, $toast) {
    var cleanupToastContainer, getToastEl, html, options, scope, setNotificationTimer, templateBase, timeoutPromises, toast; // template

    templateBase = './angularjs-toast.html';
    html = '<div class="angularjs-toast" ng-class="::$toastPlace ? \'position-fixed\' : \'position-relative\'">' + '  <ul class="toast-container" ng-class="::[$position, $containerClass]">' + '    <li class="animate-repeat" ng-repeat="data in $toastMessages track by data.id">' + '      <div class="alert alert-dismissible" ng-class="::data.toastClass">' + '        <span ng-bind-html="::data.message"></span>' + '        <a' + '          href="javascript:void(0)"' + '          class="close"' + '          data-dismiss="alert"' + '          aria-label="close"' + '          title="close"' + '          ng-click="$close($index, data.id)"' + '          ng-if="::data.dismissible"' + '          >×</a' + '        >' + '      </div>' + '    </li>' + '  </ul>' + '</div>';
    $templateCache.put(templateBase, html); // default options

    options = $toast; // scope defaults

    scope = $rootScope.$new();
    scope.$position = options.position;
    scope.$toastPlace = options.container === 'body' ? true : false;
    scope.$containerClass = options.containerClass;
    scope.$toastMessages = [];

    getToastEl = function getToastEl() {
      return document.querySelector('.angularjs-toast');
    };

    cleanupToastContainer = function cleanupToastContainer() {
      if (scope.$toastMessages.length === 0) {
        return angular.element(getToastEl()).remove();
      }
    };

    timeoutPromises = {}; // remove element besed on time interval ->timeout

    setNotificationTimer = function setNotificationTimer(msgObj, timeout) {
      timeoutPromises[msgObj.id] = $timeout(function () {
        var index;
        index = scope.$toastMessages.indexOf(msgObj);

        if (index !== -1) {
          scope.$toastMessages.splice(index, 1);
        }

        cleanupToastContainer();
      }, timeout);
    }; // close selected element
    // remove ->$index element from ->scope.toastMessages


    scope.$close = function (index, id) {
      $timeout.cancel(timeoutPromises[id]);
      delete timeoutPromises[id];
      scope.$toastMessages.splice(index, 1);
      cleanupToastContainer();
    }; // toast function


    return toast = function toast(args) {
      var dismissible, htmlTemplate, json, message, timeout, toastClass; // user options

      message = typeof args === 'string' ? args : args.message;
      timeout = args.timeout || options.timeout;
      dismissible = args.dismissible !== void 0 ? args.dismissible : options.dismissible;
      toastClass = args.className || options.defaultToastClass;

      if (!message) {
        throw new Error("Toast message is required...");
      } // values that bind to HTML
      // check if templates are present in the body
      // append to body


      htmlTemplate = angular.element(getToastEl());

      if (!htmlTemplate[0]) {
        // if the element is not appened to html
        // get default template from ->templateBase
        // append to ->options.container
        $http.get(templateBase, {
          cache: $templateCache
        }).then(function (response) {
          var el, templateElement; // compile the element
          // append default template to the ->templateBase

          templateElement = $compile(response.data)(scope);

          if (angular.isElement(options.container)) {
            el = options.container;
          } else {
            el = document.querySelector(options.container);
          }

          angular.element(el).append(templateElement);
        });
      } // append inputs to json variable
      // this will be pushed to the ->scope.$toastMessages array


      json = {
        message: message,
        id: getUniqId(),
        toastClass: toastClass,
        dismissible: dismissible
      }; // remove last/ first element from ->scope.$toastMessages when the maxlength is reached

      if (scope.$toastMessages.length === options.maxToast) {
        if (!options.insertFromTop) {
          scope.$toastMessages.shift();
        } else {
          scope.$toastMessages.pop();
        }
      } // push elements to array


      if (options.insertFromTop) {
        scope.$toastMessages.unshift(json);
      } else {
        scope.$toastMessages.push(json);
      }

      setNotificationTimer(json, timeout);
    };
  };

  $toastFactory.$inject = ['$rootScope', '$http', '$templateCache', '$compile', '$timeout', '$toast'];
  angular.module('angularjsToast', ['ngSanitize', 'ngAnimate']).provider('$toast', $toastProvider).factory('toast', $toastFactory);
}).call(void 0);
//# sourceMappingURL=angularjs-toast.js.map
